@@ -62,6 +62,22 @@ var (
 			},
 			PrivateNetworkUUID: "1fe49b6c-ac8e-11e9-98cb-3bec94f411bc",
 			Tags:               []string{"testing"},
+			StorageSizeMib:     20480,
+		},
+	}
+
+	testKafkaDBCluster = do.Database{
+		Database: &godo.Database{
+			ID:          "ea93928g-8se0-929e-m1ns-029daj2k3j12",
+			Name:        "kafka-db-cluster",
+			RegionSlug:  "nyc1",
+			EngineSlug:  "kafka",
+			VersionSlug: "3.5",
+			NumNodes:    3,
+			SizeSlug:    "db-s-2vcpu-4gb",
+			CreatedAt:   time.Now(),
+			Status:      "online",
+			Tags:        []string{"testing"},
 		},
 	}
 
@@ -177,6 +193,48 @@ var (
 		DatabaseOptions: &godo.DatabaseOptions{},
 	}
 
+	testMySQLConfiguration = do.MySQLConfig{
+		MySQLConfig: &godo.MySQLConfig{},
+	}
+
+	testPostgreSQLConfiguration = do.PostgreSQLConfig{
+		PostgreSQLConfig: &godo.PostgreSQLConfig{},
+	}
+
+	testRedisConfiguration = do.RedisConfig{
+		RedisConfig: &godo.RedisConfig{},
+	}
+
+	topicReplicationFactor = uint32(3)
+	testKafkaTopic         = do.DatabaseTopic{
+		DatabaseTopic: &godo.DatabaseTopic{
+			Name:  "topic1",
+			State: "active",
+			Config: &godo.TopicConfig{
+				CleanupPolicy: "delete",
+			},
+			Partitions: []*godo.TopicPartition{
+				{
+					Id:             0,
+					Size:           4096,
+					EarliestOffset: 0,
+					InSyncReplicas: 2,
+				},
+				{
+					Id:             1,
+					Size:           4096,
+					EarliestOffset: 4,
+					InSyncReplicas: 2,
+				},
+			},
+			ReplicationFactor: &topicReplicationFactor,
+		},
+	}
+
+	testKafkaTopics = do.DatabaseTopics{
+		testKafkaTopic,
+	}
+
 	errTest = errors.New("error")
 )
 
@@ -201,6 +259,8 @@ func TestDatabasesCommand(t *testing.T) {
 		"pool",
 		"db",
 		"sql-mode",
+		"configuration",
+		"topics",
 	)
 }
 
@@ -271,6 +331,25 @@ func TestDatabaseOptionsCommand(t *testing.T) {
 	)
 }
 
+func TestDatabaseConfigurationCommand(t *testing.T) {
+	cmd := databaseConfiguration()
+	assert.NotNil(t, cmd)
+	assertCommandNames(t, cmd, "get", "update")
+}
+
+func TestDatabaseKafkaTopicCommand(t *testing.T) {
+	cmd := databaseTopic()
+	assert.NotNil(t, cmd)
+	assertCommandNames(t, cmd,
+		"get",
+		"list",
+		"delete",
+		"create",
+		"update",
+		"partitions",
+	)
+}
+
 func TestDatabasesGet(t *testing.T) {
 	// Successful call
 	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
@@ -322,6 +401,7 @@ func TestDatabasesCreate(t *testing.T) {
 		SizeSlug:           testDBCluster.SizeSlug,
 		PrivateNetworkUUID: testDBCluster.PrivateNetworkUUID,
 		Tags:               testDBCluster.Tags,
+		StorageSizeMib:     testDBCluster.StorageSizeMib,
 	}
 
 	// Successful call
@@ -336,6 +416,7 @@ func TestDatabasesCreate(t *testing.T) {
 		config.Doit.Set(config.NS, doctl.ArgDatabaseNumNodes, testDBCluster.NumNodes)
 		config.Doit.Set(config.NS, doctl.ArgPrivateNetworkUUID, testDBCluster.PrivateNetworkUUID)
 		config.Doit.Set(config.NS, doctl.ArgTag, testDBCluster.Tags)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseStorageSizeMib, testDBCluster.StorageSizeMib)
 
 		err := RunDatabaseCreate(config)
 		assert.NoError(t, err)
@@ -488,8 +569,9 @@ func TestDatabaseMigrate(t *testing.T) {
 
 func TestDatabaseResize(t *testing.T) {
 	r := &godo.DatabaseResizeRequest{
-		SizeSlug: testDBCluster.SizeSlug,
-		NumNodes: testDBCluster.NumNodes,
+		SizeSlug:       testDBCluster.SizeSlug,
+		NumNodes:       testDBCluster.NumNodes,
+		StorageSizeMib: testDBCluster.StorageSizeMib,
 	}
 
 	// Success
@@ -498,6 +580,7 @@ func TestDatabaseResize(t *testing.T) {
 		config.Args = append(config.Args, testDBCluster.ID)
 		config.Doit.Set(config.NS, doctl.ArgSizeSlug, testDBCluster.SizeSlug)
 		config.Doit.Set(config.NS, doctl.ArgDatabaseNumNodes, testDBCluster.NumNodes)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseStorageSizeMib, testDBCluster.StorageSizeMib)
 
 		err := RunDatabaseResize(config)
 		assert.NoError(t, err)
@@ -509,6 +592,7 @@ func TestDatabaseResize(t *testing.T) {
 		config.Args = append(config.Args, testDBCluster.ID)
 		config.Doit.Set(config.NS, doctl.ArgSizeSlug, testDBCluster.SizeSlug)
 		config.Doit.Set(config.NS, doctl.ArgDatabaseNumNodes, testDBCluster.NumNodes)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseStorageSizeMib, testDBCluster.StorageSizeMib)
 
 		err := RunDatabaseResize(config)
 		assert.EqualError(t, err, errTest.Error())
@@ -535,6 +619,155 @@ func TestDatabaseListBackups(t *testing.T) {
 	})
 }
 
+func TestDatabaseListKafkaTopics(t *testing.T) {
+	// Success
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().ListTopics(testKafkaDBCluster.ID).Return(testKafkaTopics, nil)
+		config.Args = append(config.Args, testKafkaDBCluster.ID)
+
+		err := RunDatabaseTopicList(config)
+		assert.NoError(t, err)
+	})
+
+	// Error
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().ListTopics(testKafkaDBCluster.ID).Return(nil, errTest)
+		config.Args = append(config.Args, testKafkaDBCluster.ID)
+
+		err := RunDatabaseTopicList(config)
+		assert.EqualError(t, err, errTest.Error())
+	})
+}
+
+func TestDatabaseGetKafkaTopic(t *testing.T) {
+	// Success
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().GetTopic(testKafkaDBCluster.ID, testKafkaTopic.Name).Return(&testKafkaTopic, nil)
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+
+		err := RunDatabaseTopicGet(config)
+		assert.NoError(t, err)
+	})
+
+	// Error
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().GetTopic(testKafkaDBCluster.ID, testKafkaTopic.Name).Return(nil, errTest)
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+
+		err := RunDatabaseTopicGet(config)
+		assert.EqualError(t, err, errTest.Error())
+	})
+}
+
+func TestDatabaseCreateKafkaTopic(t *testing.T) {
+	// Success - only topic name
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		createReq := &godo.DatabaseCreateTopicRequest{
+			Name:   testKafkaTopic.Name,
+			Config: &godo.TopicConfig{},
+		}
+		tm.databases.EXPECT().CreateTopic(testKafkaDBCluster.ID, createReq).Return(&testKafkaTopic, nil)
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+
+		err := RunDatabaseTopicCreate(config)
+		assert.NoError(t, err)
+	})
+	// Success - with additional config
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		pc := uint32(len(testKafkaTopic.Partitions))
+		createReq := &godo.DatabaseCreateTopicRequest{
+			Name:              testKafkaTopic.Name,
+			ReplicationFactor: testKafkaTopic.ReplicationFactor,
+			PartitionCount:    &pc,
+			Config: &godo.TopicConfig{
+				CleanupPolicy: testKafkaTopic.Config.CleanupPolicy,
+			},
+		}
+		tm.databases.EXPECT().CreateTopic(testKafkaDBCluster.ID, createReq).Return(&testKafkaTopic, nil)
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseTopicPartitionCount, pc)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseTopicReplicationFactor, testKafkaTopic.ReplicationFactor)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseTopicCleanupPolicy, testKafkaTopic.Config.CleanupPolicy)
+
+		err := RunDatabaseTopicCreate(config)
+		assert.NoError(t, err)
+	})
+	// Error
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().CreateTopic(testKafkaDBCluster.ID, gomock.AssignableToTypeOf(&godo.DatabaseCreateTopicRequest{})).Return(nil, errTest)
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+
+		err := RunDatabaseTopicCreate(config)
+		assert.EqualError(t, err, errTest.Error())
+	})
+}
+
+func TestDatabaseUpdateKafkaTopic(t *testing.T) {
+	// Success - only partition count
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		currPC := uint32(len(testKafkaTopic.Partitions))
+		newPC := currPC + 1
+		updateReq := &godo.DatabaseUpdateTopicRequest{
+			PartitionCount: &newPC,
+			Config:         &godo.TopicConfig{},
+		}
+		tm.databases.EXPECT().UpdateTopic(testKafkaDBCluster.ID, testKafkaTopic.Name, updateReq).Return(nil)
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseTopicPartitionCount, newPC)
+
+		err := RunDatabaseTopicUpdate(config)
+		assert.NoError(t, err)
+	})
+	// Success - with additional config
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		currPC := uint32(len(testKafkaTopic.Partitions))
+		newPC := currPC + 1
+		updateReq := &godo.DatabaseUpdateTopicRequest{
+			PartitionCount: &newPC,
+			Config: &godo.TopicConfig{
+				CleanupPolicy: testKafkaTopic.Config.CleanupPolicy,
+			},
+		}
+		tm.databases.EXPECT().UpdateTopic(testKafkaDBCluster.ID, testKafkaTopic.Name, updateReq).Return(nil)
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseTopicPartitionCount, newPC)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseTopicCleanupPolicy, testKafkaTopic.Config.CleanupPolicy)
+
+		err := RunDatabaseTopicUpdate(config)
+		assert.NoError(t, err)
+	})
+	// Error
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().UpdateTopic(testKafkaDBCluster.ID, testKafkaTopic.Name, gomock.AssignableToTypeOf(&godo.DatabaseUpdateTopicRequest{})).Return(errTest)
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+
+		err := RunDatabaseTopicUpdate(config)
+		assert.EqualError(t, err, errTest.Error())
+	})
+}
+
+func TestDatabaseDeleteKafkaTopic(t *testing.T) {
+	// Successful
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().DeleteTopic(testKafkaDBCluster.ID, testKafkaTopic.Name).Return(nil)
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+		config.Doit.Set(config.NS, doctl.ArgForce, "true")
+
+		err := RunDatabaseTopicDelete(config)
+		assert.NoError(t, err)
+	})
+	// Error
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().DeleteTopic(testKafkaDBCluster.ID, testKafkaTopic.Name).Return(errTest)
+
+		config.Args = append(config.Args, testKafkaDBCluster.ID, testKafkaTopic.Name)
+		config.Doit.Set(config.NS, doctl.ArgForce, "true")
+
+		err := RunDatabaseTopicDelete(config)
+		assert.EqualError(t, err, errTest.Error())
+	})
+}
+
 func TestDatabaseConnectionGet(t *testing.T) {
 	// Success
 	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
@@ -1182,7 +1415,7 @@ func TestDatabaseGetSQLModes(t *testing.T) {
 }
 
 func TestDatabaseSetSQLModes(t *testing.T) {
-	testSQLModesInterface := make([]interface{}, 0, len(testSQLModes))
+	testSQLModesInterface := make([]any, 0, len(testSQLModes))
 	for _, sqlMode := range testSQLModes {
 		testSQLModesInterface = append(testSQLModesInterface, sqlMode)
 	}
@@ -1236,3 +1469,57 @@ func TestConvertUTCtoISO8601(t *testing.T) {
 
 	assert.Equal(t, "2023-02-01T17:32:15Z", isoTime)
 }
+
+func TestDatabaseConfigurationGet(t *testing.T) {
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().GetMySQLConfiguration(testDBCluster.ID).Return(&testMySQLConfiguration, nil)
+		config.Args = append(config.Args, testDBCluster.ID)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseEngine, "mysql")
+
+		err := RunDatabaseConfigurationGet(config)
+
+		assert.NoError(t, err)
+	})
+
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().GetPostgreSQLConfiguration(testDBCluster.ID).Return(&testPostgreSQLConfiguration, nil)
+		config.Args = append(config.Args, testDBCluster.ID)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseEngine, "pg")
+
+		err := RunDatabaseConfigurationGet(config)
+
+		assert.NoError(t, err)
+	})
+
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		tm.databases.EXPECT().GetRedisConfiguration(testDBCluster.ID).Return(&testRedisConfiguration, nil)
+		config.Args = append(config.Args, testDBCluster.ID)
+		config.Doit.Set(config.NS, doctl.ArgDatabaseEngine, "redis")
+
+		err := RunDatabaseConfigurationGet(config)
+
+		assert.NoError(t, err)
+	})
+
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		err := RunDatabaseConfigurationGet(config)
+
+		assert.Equal(t, err, doctl.NewMissingArgsErr(config.NS))
+	})
+
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		config.Args = append(config.Args, testDBCluster.ID, "extra arg")
+
+		err := RunDatabaseConfigurationGet(config)
+
+		assert.Equal(t, err, doctl.NewTooManyArgsErr(config.NS))
+	})
+
+	withTestClient(t, func(config *CmdConfig, tm *tcMocks) {
+		config.Args = append(config.Args, testDBCluster.ID)
+
+		err := RunDatabaseConfigurationGet(config)
+
+		assert.Error(t, err)
+	})
+}
